; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = "QCF_ab"
command = ~D, DF, F, a+b

;- qcircle

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCB_a"
command = ~D, DF, B, a

[Command]
name = "QCB_b"
command = ~D, DF, B, b

[Command]
name = "QCB_c"
command = ~D, DF, B, c


[Command]
name = "QCB_x"
command = ~D, DF, B, x

[Command]
name = "QCB_y"
command = ~D, DF, B, y

[Command]
name = "QCB_z"
command = ~D, DF, B, z


[Command]
name = "x+c"
command = x+c
time = 10 

[Command]
name = "a+c"
command = a+c
time = 10 
;------ call
;onslaught fake
[Command]
name = "z+c"
command = z+c
time = 10


[Command]
name = "b+y"
command = b+y
time = 10


[Command]
name = "a+x"
command = a+x
time = 10


[Command]
name = "a+z"
command = a+z
time = 10

[Command]
name = "y+c"
command = y+c
time = 10

[Command]
name = "b+c"
command = b+c
time = 10

[Command]
name = "x+y+z"
command = x+y+z
time = 10 

[Command]
name = "x+y"
command = x+y
time = 10 

[Command]
name = "y+a"
command = y+a
time = 10 

[Command]
name = "a+b"
command = a+b
time = 10 

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------

;-| Single Button |---------------------------------------------------------


[Command]
name = "s"
command = s
time = 1


[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "slam_1"
command = /F,z
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1



[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.

[Statedef -1]

;===========================================================================

;---------------------------------------------------------------------------
[State -1] ; call onslaught 
type = ChangeState
value = 900
triggerall = power >= 2000
triggerall = command = "QCF_ab"
trigger1 = statetype = S
trigger1 = ctrl = 1

[State -1] ; call onslaught 
type = ChangeState
value = 2500
triggerall = command = "a+c"
trigger1 = statetype != A
trigger1 = ctrl = 1


[State -1] ; teleport
type = ChangeState
value = 3904
triggerall = command = "a+b"
trigger1 = statetype != A
trigger1 = ctrl = 1


[State -1] ; fake
type = ChangeState
value = 3900
triggerall = command = "a+z"
trigger1 = statetype != A
trigger1 = ctrl = 1

;special rush
[State -1]
type = ChangeState
value = 860
triggerall = command = "x+y+z"
trigger1 = statetype != A
trigger1 = ctrl = 1

;air psycho crusher
[State -1]
type = ChangeState
value = 893
triggerall = command = "x+c"
trigger1 = statetype = A
trigger1 = ctrl = 1

;magneto slider
[State -1]
type = ChangeState
value = 855
triggerall = command = "y+c"
trigger1 = statetype != A
trigger1 = ctrl = 1

;juggernaut headcrush
[State -1]
type = ChangeState
value = 888
triggerall = command = "x+y"
trigger1 = statetype != A
trigger1 = ctrl = 1


;magneto slider air
[State -1]
type = ChangeState
value = 862
triggerall = command = "b+c"
trigger1 = statetype != A
trigger1 = ctrl = 1

;super1
[State -1]
type = ChangeState
value = 810
triggerall = command = "QCF_z"
trigger1 = statetype = S
trigger1 = ctrl = 1


;super2
[State -1]
type = ChangeState
value = 801
triggerall = command = "QCF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1

;super3
[State -1]
type = ChangeState
value = 803
triggerall = command = "QCF_x"
trigger1 = statetype = S
trigger1 = ctrl = 1

;super 4
[State -1]
type = ChangeState
value = 804
triggerall = command = "QCF_c"
trigger1 = statetype = S
trigger1 = ctrl = 1

;super power
[State -1]
type = ChangeState
value = 1233
triggerall = command = "QCF_b"
trigger1 = statetype = S
trigger1 = ctrl = 1

;super 5
[State -1]
type = ChangeState
value = 808
triggerall = command = "QCF_a"
trigger1 = statetype != A
trigger1 = ctrl = 1

;super 6
[State -1]
type = ChangeState
value = 807
triggerall = command = "y+a"
trigger1 = statetype = S
trigger1 = ctrl = 1

;call onslaught fake

[State -1]
type = ChangeState
value =  416
triggerall = command = "z+c"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = 416
trigger2 = time > 7

;call onslaught headcrusher
[State -1]
type = ChangeState
value = 660
triggerall = command = "a+x"
triggerall = command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl = 1

;change onslaught change
[State -1]
type = ChangeState
value = 417
triggerall = command = "b+y"
triggerall = command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = 417
trigger2 = time > 7

;Taunt
[State -1]
type = ChangeState
value = 195
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl = 1

;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Stand_X
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time > 7

;Stand_Y
[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = time > 7

;Stand_Z
[State -1]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 220
trigger2 = time > 7

;Stand_a
[State -1]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = time > 7

;Stand_b
[State -1]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 240
trigger2 = time > 7

;Stand_c
[State -1]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 250
trigger2 = time > 7

;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_b
[State -1]
type = ChangeState
value = 401
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 500 ;crouch_fwd_a
trigger3 = movecontact = 1

;Crouch_c
[State -1]
type = ChangeState
value = 402
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1



;Crouch_x
[State -1]
type = ChangeState
value = 410
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1


;---------------------------------------------------------------------------
;Crouch_y
[State -1]
type = ChangeState
value = 420
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 500 ;crouch_fwd_a
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_z
[State -1]
type = ChangeState
value = 430
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1


;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "a";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 601
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;Jump_c
[State -1]
type = ChangeState
value = 602
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;Jump_x
[State -1]
type = ChangeState
value = 603
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "a";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_y
[State -1]
type = ChangeState
value = 604
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;Jump_z
[State -1]
type = ChangeState
value = 605
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1


